@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import asyncio
 import re
 
 from bleak.uuids import uuidstr_to_str
@@ -27,7 +28,7 @@ def get_device_object_path(hci_device, address):
 
     Args:
         hci_device (str): Which bluetooth adapter to connect with.
-        address (str): The MAC adress of the bluetooth device.
+        address (str): The Bluetooth address of the bluetooth device.
 
     Returns:
         String representation of device object path on format
@@ -35,7 +36,7 @@ def get_device_object_path(hci_device, address):
 
     """
     if not validate_mac_address(address):
-        raise BleakError("{0} is not a valid MAC adrdess.".format(address))
+        raise BleakError("{0} is not a valid Bluetooth address.".format(address))
 
     if not validate_hci_device(hci_device):
         raise BleakError("{0} is not a valid HCI device.".format(hci_device))
@@ -49,32 +50,32 @@ def get_device_object_path(hci_device, address):
 def get_gatt_service_path(hci_device, address, service_id):
     """Get object path for a GATT Service for a Bluetooth device.
 
-        Service         org.bluez
-        Service         org.bluez
-        Interface       org.bluez.GattService1
-        Object path     [variable prefix]/{hci0,hci1,...}/dev_XX_XX_XX_XX_XX_XX/serviceXX
+    Service         org.bluez
+    Service         org.bluez
+    Interface       org.bluez.GattService1
+    Object path     [variable prefix]/{hci0,hci1,...}/dev_XX_XX_XX_XX_XX_XX/serviceXX
 
-        Args:
-            hci_device (str): Which bluetooth adapter to connect with.
-            address (str): The MAC adress of the bluetooth device.
-            service_id (int):
+    Args:
+        hci_device (str): Which bluetooth adapter to connect with.
+        address (str): The Bluetooth address of the bluetooth device.
+        service_id (int):
 
-        Returns:
-            String representation of GATT service object path on format
-            `/org/bluez/{hci0,hci1,...}/dev_XX_XX_XX_XX_XX_XX/serviceXX`.
+    Returns:
+        String representation of GATT service object path on format
+        `/org/bluez/{hci0,hci1,...}/dev_XX_XX_XX_XX_XX_XX/serviceXX`.
 
-        """
+    """
     base = get_device_object_path(hci_device, address)
     return base + "{0}/service{1:02d}".format(base, service_id)
 
 
-async def get_managed_objects(bus, loop, object_path_filter=None):
+async def get_managed_objects(bus, object_path_filter=None):
     objects = await bus.callRemote(
         "/",
         "GetManagedObjects",
         interface="org.freedesktop.DBus.ObjectManager",
         destination="org.bluez",
-    ).asFuture(loop)
+    ).asFuture(asyncio.get_event_loop())
     if object_path_filter:
         return dict(
             filter(lambda i: i[0].startswith(object_path_filter), objects.items())
