@@ -36,9 +36,7 @@ from libdispatch import dispatch_queue_create, DISPATCH_QUEUE_SERIAL
 from bleak.backends.corebluetooth.PeripheralDelegate import PeripheralDelegate
 from bleak.backends.corebluetooth.device import BLEDeviceCoreBluetooth
 
-
 logger = logging.getLogger(__name__)
-
 CBCentralManagerDelegate = objc.protocolNamed("CBCentralManagerDelegate")
 
 try:
@@ -77,6 +75,7 @@ class CentralManagerDelegate(NSObject):
 
         self.callbacks = {}
         self.disconnected_callback = None
+        self._connection_state_changed = asyncio.Event()
 
         self.central_manager = CBCentralManager.alloc().initWithDelegate_queue_(
             self, dispatch_queue_create(b"bleak.corebluetooth", DISPATCH_QUEUE_SERIAL)
@@ -142,18 +141,29 @@ class CentralManagerDelegate(NSObject):
         await asyncio.sleep(float(scan_options.get("timeout", 0.0)))
         return await self.stop_scan()
 
-    async def connect_(self, peripheral: CBPeripheral) -> bool:
+    async def connect_(self, peripheral: CBPeripheral, timeout=10.0) -> bool:
         self._connection_state = CMDConnectionState.PENDING
+        self._connection_state_changed.clear()
         self.central_manager.connectPeripheral_options_(peripheral, None)
 
-        while self._connection_state == CMDConnectionState.PENDING:
-            await asyncio.sleep(0)
+        try:
+            await asyncio.wait_for(
+                self._connection_state_changed.wait(), timeout=timeout
+            )
+        except asyncio.TimeoutError:
+            logger.debug(f"Connection timed out after {timeout} seconds.")
+            self.central_manager.cancelPeripheralConnection_(peripheral)
+            raise
 
         self.connected_peripheral = peripheral
 
         return self._connection_state == CMDConnectionState.CONNECTED
 
     async def disconnect(self) -> bool:
+        # Is a peripheral even connected?
+        if self.connected_peripheral is None:
+            return True
+
         self._connection_state = CMDConnectionState.PENDING
         self.central_manager.cancelPeripheralConnection_(self.connected_peripheral)
 
@@ -187,7 +197,8 @@ class CentralManagerDelegate(NSObject):
     def centralManagerDidUpdateState_(self, centralManager):
         logger.debug("centralManagerDidUpdateState_")
         self.event_loop.call_soon_threadsafe(
-            self.did_update_state, centralManager,
+            self.did_update_state,
+            centralManager,
         )
 
     @objc.python_method
@@ -234,8 +245,8 @@ class CentralManagerDelegate(NSObject):
                 callback(peripheral, advertisementData, RSSI)
 
         logger.debug(
-            "Discovered device {}: {} @ RSSI: {} (kCBAdvData {})".format(
-                uuid_string, device.name, RSSI, advertisementData.keys()
+            "Discovered device {}: {} @ RSSI: {} (kCBAdvData {}) and Central: {}".format(
+                uuid_string, device.name, RSSI, advertisementData.keys(), central
             )
         )
 
@@ -248,7 +259,11 @@ class CentralManagerDelegate(NSObject):
     ):
         logger.debug("centralManager_didDiscoverPeripheral_advertisementData_RSSI_")
         self.event_loop.call_soon_threadsafe(
-            self.did_discover_peripheral, central, peripheral, advertisementData, RSSI,
+            self.did_discover_peripheral,
+            central,
+            peripheral,
+            advertisementData,
+            RSSI,
         )
 
     @objc.python_method
@@ -264,11 +279,14 @@ class CentralManagerDelegate(NSObject):
             )
             self.connected_peripheral_delegate = peripheralDelegate
             self._connection_state = CMDConnectionState.CONNECTED
+            self._connection_state_changed.set()
 
     def centralManager_didConnectPeripheral_(self, central, peripheral):
         logger.debug("centralManager_didConnectPeripheral_")
         self.event_loop.call_soon_threadsafe(
-            self.did_connect_peripheral, central, peripheral,
+            self.did_connect_peripheral,
+            central,
+            peripheral,
         )
 
     @objc.python_method
@@ -281,13 +299,17 @@ class CentralManagerDelegate(NSObject):
             )
         )
         self._connection_state = CMDConnectionState.DISCONNECTED
+        self._connection_state_changed.set()
 
     def centralManager_didFailToConnectPeripheral_error_(
         self, centralManager: CBCentralManager, peripheral: CBPeripheral, error: NSError
     ):
         logger.debug("centralManager_didFailToConnectPeripheral_error_")
         self.event_loop.call_soon_threadsafe(
-            self.did_fail_to_connect_peripheral, centralManager, peripheral, error,
+            self.did_fail_to_connect_peripheral,
+            centralManager,
+            peripheral,
+            error,
         )
 
     @objc.python_method
@@ -307,7 +329,10 @@ class CentralManagerDelegate(NSObject):
     ):
         logger.debug("centralManager_didDisconnectPeripheral_error_")
         self.event_loop.call_soon_threadsafe(
-            self.did_disconnect_peripheral, central, peripheral, error,
+            self.did_disconnect_peripheral,
+            central,
+            peripheral,
+            error,
         )
 
 
