@@ -219,7 +219,9 @@ class PeripheralDelegate(NSObject):
     ) -> None:
         logger.debug("peripheral_didDiscoverServices_")
         self._event_loop.call_soon_threadsafe(
-            self.did_discover_services, peripheral, error,
+            self.did_discover_services,
+            peripheral,
+            error,
         )
 
     @objc.python_method
@@ -244,7 +246,10 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didDiscoverCharacteristicsForService_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_discover_characteristics_for_service, peripheral, service, error,
+            self.did_discover_characteristics_for_service,
+            peripheral,
+            service,
+            error,
         )
 
     @objc.python_method
@@ -336,7 +341,10 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didUpdateValueForDescriptor_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_update_value_for_descriptor, peripheral, descriptor, error,
+            self.did_update_value_for_descriptor,
+            peripheral,
+            descriptor,
+            error,
         )
 
     @objc.python_method
@@ -362,7 +370,10 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didWriteValueForCharacteristic_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_write_value_for_characteristic, peripheral, characteristic, error,
+            self.did_write_value_for_characteristic,
+            peripheral,
+            characteristic,
+            error,
         )
 
     @objc.python_method
@@ -385,7 +396,10 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didWriteValueForDescriptor_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_write_value_for_descriptor, peripheral, descriptor, error,
+            self.did_write_value_for_descriptor,
+            peripheral,
+            descriptor,
+            error,
         )
 
     @objc.python_method
