@@ -22,6 +22,7 @@ from bleak.backends.corebluetooth.characteristic import (
 from bleak.backends.corebluetooth.descriptor import BleakGATTDescriptorCoreBluetooth
 from bleak.backends.corebluetooth.scanner import BleakScannerCoreBluetooth
 from bleak.backends.corebluetooth.service import BleakGATTServiceCoreBluetooth
+from bleak.backends.corebluetooth.utils import cb_uuid_to_str
 from bleak.backends.device import BLEDevice
 from bleak.backends.service import BleakGATTServiceCollection
 from bleak.backends.characteristic import BleakGATTCharacteristic
@@ -47,10 +48,12 @@ class BleakClientCoreBluetooth(BaseBleakClient):
 
         if isinstance(address_or_ble_device, BLEDevice):
             self._device_info = address_or_ble_device.details
+            self._central_manager_delegate = address_or_ble_device.metadata.get(
+                "delegate"
+            )
         else:
             self._device_info = None
-
-        self._device_info = None
+            self._central_manager_delegate = None
         self._requester = None
         self._callbacks = {}
         self._services = None
@@ -68,23 +71,25 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             Boolean representing connection status.
 
         """
+        timeout = kwargs.get("timeout", self._timeout)
         if self._device_info is None:
-            timeout = kwargs.get("timeout", self._timeout)
             device = await BleakScannerCoreBluetooth.find_device_by_address(
                 self.address, timeout=timeout
             )
 
             if device:
                 self._device_info = device.details
+                self._central_manager_delegate = device.metadata.get("delegate")
             else:
                 raise BleakError(
                     "Device with address {} was not found".format(self.address)
                 )
+        # self._device_info.manager() should return a CBCentralManager
 
+        manager = self._central_manager_delegate
+        logger.debug("CentralManagerDelegate  at {}".format(manager))
         logger.debug("Connecting to BLE device @ {}".format(self.address))
-
-        manager = self._device_info.manager().delegate()
-        await manager.connect_(self._device_info)
+        await manager.connect_(self._device_info, timeout=timeout)
         manager.disconnected_callback = self._disconnected_callback_client
 
         # Now get services
@@ -104,7 +109,9 @@ class BleakClientCoreBluetooth(BaseBleakClient):
 
     async def disconnect(self) -> bool:
         """Disconnect from the peripheral device"""
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
+        if manager is None:
+            return False
         await manager.disconnect()
         self.services = BleakGATTServiceCollection()
         # Ensure that `get_services` retrieves services again, rather than using the cached object
@@ -114,7 +121,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
 
     async def is_connected(self) -> bool:
         """Checks for current active connection"""
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
         return manager.isConnected
 
     async def pair(self, *args, **kwargs) -> bool:
@@ -157,7 +164,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             return self.services
 
         logger.debug("Retrieving services...")
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
         services = await manager.connected_peripheral_delegate.discoverServices()
 
         for service in services:
@@ -165,8 +172,10 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             logger.debug(
                 "Retrieving characteristics for service {}".format(serviceUUID)
             )
-            characteristics = await manager.connected_peripheral_delegate.discoverCharacteristics_(
-                service
+            characteristics = (
+                await manager.connected_peripheral_delegate.discoverCharacteristics_(
+                    service
+                )
             )
 
             self.services.add_service(BleakGATTServiceCoreBluetooth(service))
@@ -176,8 +185,10 @@ class BleakClientCoreBluetooth(BaseBleakClient):
                 logger.debug(
                     "Retrieving descriptors for characteristic {}".format(cUUID)
                 )
-                descriptors = await manager.connected_peripheral_delegate.discoverDescriptors_(
-                    characteristic
+                descriptors = (
+                    await manager.connected_peripheral_delegate.discoverDescriptors_(
+                        characteristic
+                    )
                 )
 
                 self.services.add_characteristic(
@@ -187,11 +198,11 @@ class BleakClientCoreBluetooth(BaseBleakClient):
                     self.services.add_descriptor(
                         BleakGATTDescriptorCoreBluetooth(
                             descriptor,
-                            characteristic.UUID().UUIDString(),
+                            cb_uuid_to_str(characteristic.UUID()),
                             int(characteristic.handle()),
                         )
                     )
-        logger.info("Services resolved for %s", str(self))
+        logger.debug("Services resolved for %s", str(self))
         self._services_resolved = True
         self._services = services
         return self.services
@@ -215,7 +226,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             (bytearray) The read data.
 
         """
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
 
         if not isinstance(char_specifier, BleakGATTCharacteristic):
             characteristic = self.services.get_characteristic(char_specifier)
@@ -244,7 +255,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
         Returns:
             (bytearray) The read data.
         """
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
 
         descriptor = self.services.get_descriptor(handle)
         if not descriptor:
@@ -278,7 +289,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             response (bool): If write-with-response operation should be done. Defaults to `False`.
 
         """
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
 
         if not isinstance(char_specifier, BleakGATTCharacteristic):
             characteristic = self.services.get_characteristic(char_specifier)
@@ -288,12 +299,14 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             raise BleakError("Characteristic {} was not found!".format(char_specifier))
 
         value = NSData.alloc().initWithBytes_length_(data, len(data))
-        success = await manager.connected_peripheral_delegate.writeCharacteristic_value_type_(
-            characteristic.obj,
-            value,
-            CBCharacteristicWriteWithResponse
-            if response
-            else CBCharacteristicWriteWithoutResponse,
+        success = (
+            await manager.connected_peripheral_delegate.writeCharacteristic_value_type_(
+                characteristic.obj,
+                value,
+                CBCharacteristicWriteWithResponse
+                if response
+                else CBCharacteristicWriteWithoutResponse,
+            )
         )
         if success:
             logger.debug(
@@ -314,7 +327,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             data (bytes or bytearray): The data to send.
 
         """
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
 
         descriptor = self.services.get_descriptor(handle)
         if not descriptor:
@@ -357,7 +370,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
             callback (function): The function to be called on notification.
 
         """
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
 
         if not isinstance(char_specifier, BleakGATTCharacteristic):
             characteristic = self.services.get_characteristic(char_specifier)
@@ -388,7 +401,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
 
 
         """
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
 
         if not isinstance(char_specifier, BleakGATTCharacteristic):
             characteristic = self.services.get_characteristic(char_specifier)
@@ -409,7 +422,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
         """To get RSSI value in dBm of the connected Peripheral"""
 
         self._device_info.readRSSI()
-        manager = self._device_info.manager().delegate()
+        manager = self._central_manager_delegate
         RSSI = manager.connected_peripheral.RSSI()
         for i in range(20):  # First time takes a little otherwise returns None
             RSSI = manager.connected_peripheral.RSSI()
